alias ebuild-sync='rsync -av ./ /usr/portage/${PWD#/usr/local/src/gentoo/repo/gentoo/} --exclude ChangeLog --exclude CVS --exclude metadata.xml --delete'
alias ebuild-emerge='sudo emerge -1av $(echo ${PWD} | awk -F/ "{printf \"%s/%s\", \$(NF-1), \$(NF)}")'
alias ekeyword='ekeyword -v -q'
alias repoman='repoman -q -q'
alias rf='/usr/local/src/gentoo/portage/repoman/bin/repoman.git -q full'

_echangelog() {
	[[ ! -e ChangeLog ]] \
		&& echo "No ChangeLog" \
		&& return 1
	echangelog "$@" || return 1
}
er() {
	repoman commit "${@:1:$#-1}" -m "${@:$#}" || return 1
}
ec() {
	(
	_echangelog "$@" || exit 1
	cvs commit -m "$@" || exit 1
	)
}

att() {
	while [[ $# -gt 0 ]] ; do
		declare url=$1 tmp=$(mktemp) filename || return 1
		[[ ${url} == */* ]] || url="http://bugs.gentoo.org/attachment.cgi?id=${url}"
		printf '%s -> ' "${url}"
		if eval $(wget -S -O"${tmp}" "${url}" 2>&1 |
			grep 'Content-disposition:' | sed 's/.* //') && \
			mv "${tmp}" "${filename}" && \
			chmod $(printf "%03o" "$((0666 & ~$(umask)))") "${filename}" ; then
			du -b "${filename}"
		else
			echo "FAIL"
			rm -f "${tmp}"
		fi
		shift
	done
}
arch_emails() {
	local ret
	if [[ $@ == *.ebuild* ]] ; then
		local e keys
		for e in "$@" ; do
			keys=$(sed -n '/^[[:space:]]*KEYWORD/{s:.*=::;s:"::g;p}' ${e})
			for a in ${keys} ; do
				[[ ${a} != ~* ]] && continue
				case ${a} in
				*-*) continue ;;
				~arm64|~m68k|~mips|~s390|~sh) continue ;;
				~*) ret="${ret} ${a}" ;;
				esac
			done
		done
	else
		ret="$*"
	fi
	printf '%s@gentoo.org,' ${ret//\~}
	echo
}
stable_arch_emails() {
	arch_emails "$@" | sed -r -e 's:([^ ]*-[^ ]*|mips)@[^ ]*::g'
}
eget_maintainer() {
	local f=${1:-metadata.xml}
	local maintainer=$(xml sel -t -v pkgmetadata/herd $f)
	if [[ ${maintainer:-no-herd} == "no-herd" ]] ; then
		maintainer=$(xml sel -t -v pkgmetadata/maintainer/email $f)
	elif [[ -n ${maintainer} ]] ; then
		maintainer="${maintainer}@gentoo.org"
	fi
	if [[ -z ${maintainer} ]] ; then
		echo "No maintainer found in $f"
		return 1
	fi
	echo ${maintainer}
	return 0
}
submit_bug_stable() {
	local msg="doit"
	if [[ $1 == "-m" ]] ; then
		msg=$2
		shift 2
	fi
	if [[ -z $1 ]] || [[ -n $2 ]] ; then
		echo "Usage: submit_bug_stable <ebuilds>"
		return 1
	fi
	local maintainer
	maintainer=$(eget_maintainer) || return 1
	local cat=$(basename $(dirname $(pwd)))
	local pkg=${1%.ebuild}
	local ebuild=${pkg}.ebuild
	local cc=$(stable_arch_emails ${ebuild})
	if [[ -z ${cc} ]] ; then
		echo "Unable to read ebuild '${ebuild}'"
		return 1
	fi
	if [[ ${maintainer} == *" "* ]] ; then
		cc+=",${maintainer#* }"
		maintainer=${maintainer%% *}
	fi
	gbugz \
		post \
		--batch \
		-t "${cat}/${pkg}: stabilize" \
		-d "${msg}" \
		-a "${maintainer}" \
		--cc="${cc// /,}" \
		-k STABLEREQ \
		--product='Gentoo Linux' \
		--component=Ebuilds \
		--priority=Normal \
		--severity=enhancement
}

eskeys() {
	local k cat
	if [[ ! -e ChangeLog ]] ; then
		# running in a category rather than package
		cat="/"
	fi
	[[ -z $* ]] && set -- arm64 m68k s390 sh
	for k in "$@" ; do
		ekeyword "${k}=x86" $(grep -l "KEYWORDS.*${k}" *${cat}*.ebuild)
	done
}
_erit() {
	local msg=$1 ; shift
	[[ $1 == [[:digit:]]* ]] && msg="$msg #$1" && shift
	echo git commit -m "$(echo $@ | sed 's: :/:g') $msg"
	git commit -m "$(echo $@ | sed 's: :/:g') $msg"
}
erstable() { _erit stable "$@" ; }
erlove() { _erit love "$@" ; }

export PORTAGE_INST_UID=${UID}
export PORTAGE_INST_GID=`id -g`
